# -*- coding: utf-8 -*-
"""`Concordance between NIC2008 and ISIC4 <https://www.mospi.gov.in/sites/default/files/main_menu/national_industrial_classification/nic_2008_17apr09.pdf>`_.

The basis for this concordance comes from the document referenced above:

``48. The structure of NIC-2008 is identical to the structure of ISIC Rev. 4 up to 4-digit
level ‘class’. Classes were then divided into 5-digit ‘sub classes’ according to national
requirements.``
"""
from ...types import Concordance, Standards
from ..isic4 import ISIC4
from . import NIC2008

NIC2008_to_ISIC4 = Concordance(
    src=NIC2008,
    dst=ISIC4,
    concordances=[
        ((Standards.NIC2008, "01"), (Standards.ISIC4, "01")),
        ((Standards.NIC2008, "011"), (Standards.ISIC4, "011")),
        ((Standards.NIC2008, "0111"), (Standards.ISIC4, "0111")),
        ((Standards.NIC2008, "0112"), (Standards.ISIC4, "0112")),
        ((Standards.NIC2008, "0113"), (Standards.ISIC4, "0113")),
        ((Standards.NIC2008, "0114"), (Standards.ISIC4, "0114")),
        ((Standards.NIC2008, "0115"), (Standards.ISIC4, "0115")),
        ((Standards.NIC2008, "0116"), (Standards.ISIC4, "0116")),
        ((Standards.NIC2008, "0119"), (Standards.ISIC4, "0119")),
        ((Standards.NIC2008, "012"), (Standards.ISIC4, "012")),
        ((Standards.NIC2008, "0121"), (Standards.ISIC4, "0121")),
        ((Standards.NIC2008, "0122"), (Standards.ISIC4, "0122")),
        ((Standards.NIC2008, "0123"), (Standards.ISIC4, "0123")),
        ((Standards.NIC2008, "0124"), (Standards.ISIC4, "0124")),
        ((Standards.NIC2008, "0125"), (Standards.ISIC4, "0125")),
        ((Standards.NIC2008, "0126"), (Standards.ISIC4, "0126")),
        ((Standards.NIC2008, "0127"), (Standards.ISIC4, "0127")),
        ((Standards.NIC2008, "0128"), (Standards.ISIC4, "0128")),
        ((Standards.NIC2008, "0129"), (Standards.ISIC4, "0129")),
        ((Standards.NIC2008, "013"), (Standards.ISIC4, "013")),
        ((Standards.NIC2008, "0130"), (Standards.ISIC4, "0130")),
        ((Standards.NIC2008, "014"), (Standards.ISIC4, "014")),
        ((Standards.NIC2008, "0141"), (Standards.ISIC4, "0141")),
        ((Standards.NIC2008, "0142"), (Standards.ISIC4, "0142")),
        ((Standards.NIC2008, "0143"), (Standards.ISIC4, "0143")),
        ((Standards.NIC2008, "0144"), (Standards.ISIC4, "0144")),
        ((Standards.NIC2008, "0145"), (Standards.ISIC4, "0145")),
        ((Standards.NIC2008, "0146"), (Standards.ISIC4, "0146")),
        ((Standards.NIC2008, "0149"), (Standards.ISIC4, "0149")),
        ((Standards.NIC2008, "015"), (Standards.ISIC4, "015")),
        ((Standards.NIC2008, "0150"), (Standards.ISIC4, "0150")),
        ((Standards.NIC2008, "016"), (Standards.ISIC4, "016")),
        ((Standards.NIC2008, "0161"), (Standards.ISIC4, "0161")),
        ((Standards.NIC2008, "0162"), (Standards.ISIC4, "0162")),
        ((Standards.NIC2008, "0163"), (Standards.ISIC4, "0163")),
        ((Standards.NIC2008, "0164"), (Standards.ISIC4, "0164")),
        ((Standards.NIC2008, "017"), (Standards.ISIC4, "017")),
        ((Standards.NIC2008, "0170"), (Standards.ISIC4, "0170")),
        ((Standards.NIC2008, "02"), (Standards.ISIC4, "02")),
        ((Standards.NIC2008, "021"), (Standards.ISIC4, "021")),
        ((Standards.NIC2008, "0210"), (Standards.ISIC4, "0210")),
        ((Standards.NIC2008, "022"), (Standards.ISIC4, "022")),
        ((Standards.NIC2008, "0220"), (Standards.ISIC4, "0220")),
        ((Standards.NIC2008, "023"), (Standards.ISIC4, "023")),
        ((Standards.NIC2008, "0230"), (Standards.ISIC4, "0230")),
        ((Standards.NIC2008, "024"), (Standards.ISIC4, "024")),
        ((Standards.NIC2008, "0240"), (Standards.ISIC4, "0240")),
        ((Standards.NIC2008, "03"), (Standards.ISIC4, "03")),
        ((Standards.NIC2008, "031"), (Standards.ISIC4, "031")),
        ((Standards.NIC2008, "0311"), (Standards.ISIC4, "0311")),
        ((Standards.NIC2008, "0312"), (Standards.ISIC4, "0312")),
        ((Standards.NIC2008, "032"), (Standards.ISIC4, "032")),
        ((Standards.NIC2008, "0321"), (Standards.ISIC4, "0321")),
        ((Standards.NIC2008, "0322"), (Standards.ISIC4, "0322")),
        ((Standards.NIC2008, "05"), (Standards.ISIC4, "05")),
        ((Standards.NIC2008, "051"), (Standards.ISIC4, "051")),
        ((Standards.NIC2008, "0510"), (Standards.ISIC4, "0510")),
        ((Standards.NIC2008, "052"), (Standards.ISIC4, "052")),
        ((Standards.NIC2008, "0520"), (Standards.ISIC4, "0520")),
        ((Standards.NIC2008, "06"), (Standards.ISIC4, "06")),
        ((Standards.NIC2008, "061"), (Standards.ISIC4, "061")),
        ((Standards.NIC2008, "0610"), (Standards.ISIC4, "0610")),
        ((Standards.NIC2008, "062"), (Standards.ISIC4, "062")),
        ((Standards.NIC2008, "0620"), (Standards.ISIC4, "0620")),
        ((Standards.NIC2008, "07"), (Standards.ISIC4, "07")),
        ((Standards.NIC2008, "071"), (Standards.ISIC4, "071")),
        ((Standards.NIC2008, "0710"), (Standards.ISIC4, "0710")),
        ((Standards.NIC2008, "072"), (Standards.ISIC4, "072")),
        ((Standards.NIC2008, "0721"), (Standards.ISIC4, "0721")),
        ((Standards.NIC2008, "0729"), (Standards.ISIC4, "0729")),
        ((Standards.NIC2008, "08"), (Standards.ISIC4, "08")),
        ((Standards.NIC2008, "081"), (Standards.ISIC4, "081")),
        ((Standards.NIC2008, "0810"), (Standards.ISIC4, "0810")),
        ((Standards.NIC2008, "089"), (Standards.ISIC4, "089")),
        ((Standards.NIC2008, "0891"), (Standards.ISIC4, "0891")),
        ((Standards.NIC2008, "0892"), (Standards.ISIC4, "0892")),
        ((Standards.NIC2008, "0893"), (Standards.ISIC4, "0893")),
        ((Standards.NIC2008, "0899"), (Standards.ISIC4, "0899")),
        ((Standards.NIC2008, "09"), (Standards.ISIC4, "09")),
        ((Standards.NIC2008, "091"), (Standards.ISIC4, "091")),
        ((Standards.NIC2008, "0910"), (Standards.ISIC4, "0910")),
        ((Standards.NIC2008, "099"), (Standards.ISIC4, "099")),
        ((Standards.NIC2008, "0990"), (Standards.ISIC4, "0990")),
        ((Standards.NIC2008, "10"), (Standards.ISIC4, "10")),
        ((Standards.NIC2008, "101"), (Standards.ISIC4, "101")),
        ((Standards.NIC2008, "1010"), (Standards.ISIC4, "1010")),
        ((Standards.NIC2008, "102"), (Standards.ISIC4, "102")),
        ((Standards.NIC2008, "1020"), (Standards.ISIC4, "1020")),
        ((Standards.NIC2008, "103"), (Standards.ISIC4, "103")),
        ((Standards.NIC2008, "1030"), (Standards.ISIC4, "1030")),
        ((Standards.NIC2008, "104"), (Standards.ISIC4, "104")),
        ((Standards.NIC2008, "1040"), (Standards.ISIC4, "1040")),
        ((Standards.NIC2008, "105"), (Standards.ISIC4, "105")),
        ((Standards.NIC2008, "1050"), (Standards.ISIC4, "1050")),
        ((Standards.NIC2008, "106"), (Standards.ISIC4, "106")),
        ((Standards.NIC2008, "1061"), (Standards.ISIC4, "1061")),
        ((Standards.NIC2008, "1062"), (Standards.ISIC4, "1062")),
        ((Standards.NIC2008, "107"), (Standards.ISIC4, "107")),
        ((Standards.NIC2008, "1071"), (Standards.ISIC4, "1071")),
        ((Standards.NIC2008, "1072"), (Standards.ISIC4, "1072")),
        ((Standards.NIC2008, "1073"), (Standards.ISIC4, "1073")),
        ((Standards.NIC2008, "1074"), (Standards.ISIC4, "1074")),
        ((Standards.NIC2008, "1075"), (Standards.ISIC4, "1075")),
        ((Standards.NIC2008, "1079"), (Standards.ISIC4, "1079")),
        ((Standards.NIC2008, "108"), (Standards.ISIC4, "108")),
        ((Standards.NIC2008, "1080"), (Standards.ISIC4, "1080")),
        ((Standards.NIC2008, "11"), (Standards.ISIC4, "11")),
        ((Standards.NIC2008, "110"), (Standards.ISIC4, "110")),
        ((Standards.NIC2008, "1101"), (Standards.ISIC4, "1101")),
        ((Standards.NIC2008, "1102"), (Standards.ISIC4, "1102")),
        ((Standards.NIC2008, "1103"), (Standards.ISIC4, "1103")),
        ((Standards.NIC2008, "1104"), (Standards.ISIC4, "1104")),
        ((Standards.NIC2008, "12"), (Standards.ISIC4, "12")),
        ((Standards.NIC2008, "120"), (Standards.ISIC4, "120")),
        ((Standards.NIC2008, "1200"), (Standards.ISIC4, "1200")),
        ((Standards.NIC2008, "13"), (Standards.ISIC4, "13")),
        ((Standards.NIC2008, "131"), (Standards.ISIC4, "131")),
        ((Standards.NIC2008, "1311"), (Standards.ISIC4, "1311")),
        ((Standards.NIC2008, "1312"), (Standards.ISIC4, "1312")),
        ((Standards.NIC2008, "1313"), (Standards.ISIC4, "1313")),
        ((Standards.NIC2008, "139"), (Standards.ISIC4, "139")),
        ((Standards.NIC2008, "1391"), (Standards.ISIC4, "1391")),
        ((Standards.NIC2008, "1392"), (Standards.ISIC4, "1392")),
        ((Standards.NIC2008, "1393"), (Standards.ISIC4, "1393")),
        ((Standards.NIC2008, "1394"), (Standards.ISIC4, "1394")),
        ((Standards.NIC2008, "1399"), (Standards.ISIC4, "1399")),
        ((Standards.NIC2008, "14"), (Standards.ISIC4, "14")),
        ((Standards.NIC2008, "141"), (Standards.ISIC4, "141")),
        ((Standards.NIC2008, "1410"), (Standards.ISIC4, "1410")),
        ((Standards.NIC2008, "142"), (Standards.ISIC4, "142")),
        ((Standards.NIC2008, "1420"), (Standards.ISIC4, "1420")),
        ((Standards.NIC2008, "143"), (Standards.ISIC4, "143")),
        ((Standards.NIC2008, "1430"), (Standards.ISIC4, "1430")),
        ((Standards.NIC2008, "15"), (Standards.ISIC4, "15")),
        ((Standards.NIC2008, "151"), (Standards.ISIC4, "151")),
        ((Standards.NIC2008, "1511"), (Standards.ISIC4, "1511")),
        ((Standards.NIC2008, "1512"), (Standards.ISIC4, "1512")),
        ((Standards.NIC2008, "152"), (Standards.ISIC4, "152")),
        ((Standards.NIC2008, "1520"), (Standards.ISIC4, "1520")),
        ((Standards.NIC2008, "16"), (Standards.ISIC4, "16")),
        ((Standards.NIC2008, "161"), (Standards.ISIC4, "161")),
        ((Standards.NIC2008, "1610"), (Standards.ISIC4, "1610")),
        ((Standards.NIC2008, "162"), (Standards.ISIC4, "162")),
        ((Standards.NIC2008, "1621"), (Standards.ISIC4, "1621")),
        ((Standards.NIC2008, "1622"), (Standards.ISIC4, "1622")),
        ((Standards.NIC2008, "1623"), (Standards.ISIC4, "1623")),
        ((Standards.NIC2008, "1629"), (Standards.ISIC4, "1629")),
        ((Standards.NIC2008, "17"), (Standards.ISIC4, "17")),
        ((Standards.NIC2008, "170"), (Standards.ISIC4, "170")),
        ((Standards.NIC2008, "1701"), (Standards.ISIC4, "1701")),
        ((Standards.NIC2008, "1702"), (Standards.ISIC4, "1702")),
        ((Standards.NIC2008, "1709"), (Standards.ISIC4, "1709")),
        ((Standards.NIC2008, "18"), (Standards.ISIC4, "18")),
        ((Standards.NIC2008, "181"), (Standards.ISIC4, "181")),
        ((Standards.NIC2008, "1811"), (Standards.ISIC4, "1811")),
        ((Standards.NIC2008, "1812"), (Standards.ISIC4, "1812")),
        ((Standards.NIC2008, "182"), (Standards.ISIC4, "182")),
        ((Standards.NIC2008, "1820"), (Standards.ISIC4, "1820")),
        ((Standards.NIC2008, "19"), (Standards.ISIC4, "19")),
        ((Standards.NIC2008, "191"), (Standards.ISIC4, "191")),
        ((Standards.NIC2008, "1910"), (Standards.ISIC4, "1910")),
        ((Standards.NIC2008, "192"), (Standards.ISIC4, "192")),
        ((Standards.NIC2008, "1920"), (Standards.ISIC4, "1920")),
        ((Standards.NIC2008, "20"), (Standards.ISIC4, "20")),
        ((Standards.NIC2008, "201"), (Standards.ISIC4, "201")),
        ((Standards.NIC2008, "2011"), (Standards.ISIC4, "2011")),
        ((Standards.NIC2008, "2012"), (Standards.ISIC4, "2012")),
        ((Standards.NIC2008, "2013"), (Standards.ISIC4, "2013")),
        ((Standards.NIC2008, "202"), (Standards.ISIC4, "202")),
        ((Standards.NIC2008, "2021"), (Standards.ISIC4, "2021")),
        ((Standards.NIC2008, "2022"), (Standards.ISIC4, "2022")),
        ((Standards.NIC2008, "2023"), (Standards.ISIC4, "2023")),
        ((Standards.NIC2008, "2029"), (Standards.ISIC4, "2029")),
        ((Standards.NIC2008, "203"), (Standards.ISIC4, "203")),
        ((Standards.NIC2008, "2030"), (Standards.ISIC4, "2030")),
        ((Standards.NIC2008, "21"), (Standards.ISIC4, "21")),
        ((Standards.NIC2008, "210"), (Standards.ISIC4, "210")),
        ((Standards.NIC2008, "2100"), (Standards.ISIC4, "2100")),
        ((Standards.NIC2008, "22"), (Standards.ISIC4, "22")),
        ((Standards.NIC2008, "221"), (Standards.ISIC4, "221")),
        ((Standards.NIC2008, "2211"), (Standards.ISIC4, "2211")),
        ((Standards.NIC2008, "2219"), (Standards.ISIC4, "2219")),
        ((Standards.NIC2008, "222"), (Standards.ISIC4, "222")),
        ((Standards.NIC2008, "2220"), (Standards.ISIC4, "2220")),
        ((Standards.NIC2008, "23"), (Standards.ISIC4, "23")),
        ((Standards.NIC2008, "231"), (Standards.ISIC4, "231")),
        ((Standards.NIC2008, "2310"), (Standards.ISIC4, "2310")),
        ((Standards.NIC2008, "239"), (Standards.ISIC4, "239")),
        ((Standards.NIC2008, "2391"), (Standards.ISIC4, "2391")),
        ((Standards.NIC2008, "2392"), (Standards.ISIC4, "2392")),
        ((Standards.NIC2008, "2393"), (Standards.ISIC4, "2393")),
        ((Standards.NIC2008, "2394"), (Standards.ISIC4, "2394")),
        ((Standards.NIC2008, "2395"), (Standards.ISIC4, "2395")),
        ((Standards.NIC2008, "2396"), (Standards.ISIC4, "2396")),
        ((Standards.NIC2008, "2399"), (Standards.ISIC4, "2399")),
        ((Standards.NIC2008, "24"), (Standards.ISIC4, "24")),
        ((Standards.NIC2008, "241"), (Standards.ISIC4, "241")),
        ((Standards.NIC2008, "2410"), (Standards.ISIC4, "2410")),
        ((Standards.NIC2008, "242"), (Standards.ISIC4, "242")),
        ((Standards.NIC2008, "2420"), (Standards.ISIC4, "2420")),
        ((Standards.NIC2008, "243"), (Standards.ISIC4, "243")),
        ((Standards.NIC2008, "2431"), (Standards.ISIC4, "2431")),
        ((Standards.NIC2008, "2432"), (Standards.ISIC4, "2432")),
        ((Standards.NIC2008, "25"), (Standards.ISIC4, "25")),
        ((Standards.NIC2008, "251"), (Standards.ISIC4, "251")),
        ((Standards.NIC2008, "2511"), (Standards.ISIC4, "2511")),
        ((Standards.NIC2008, "2512"), (Standards.ISIC4, "2512")),
        ((Standards.NIC2008, "2513"), (Standards.ISIC4, "2513")),
        ((Standards.NIC2008, "252"), (Standards.ISIC4, "252")),
        ((Standards.NIC2008, "2520"), (Standards.ISIC4, "2520")),
        ((Standards.NIC2008, "259"), (Standards.ISIC4, "259")),
        ((Standards.NIC2008, "2591"), (Standards.ISIC4, "2591")),
        ((Standards.NIC2008, "2592"), (Standards.ISIC4, "2592")),
        ((Standards.NIC2008, "2593"), (Standards.ISIC4, "2593")),
        ((Standards.NIC2008, "2599"), (Standards.ISIC4, "2599")),
        ((Standards.NIC2008, "26"), (Standards.ISIC4, "26")),
        ((Standards.NIC2008, "261"), (Standards.ISIC4, "261")),
        ((Standards.NIC2008, "2610"), (Standards.ISIC4, "2610")),
        ((Standards.NIC2008, "262"), (Standards.ISIC4, "262")),
        ((Standards.NIC2008, "2620"), (Standards.ISIC4, "2620")),
        ((Standards.NIC2008, "263"), (Standards.ISIC4, "263")),
        ((Standards.NIC2008, "2630"), (Standards.ISIC4, "2630")),
        ((Standards.NIC2008, "264"), (Standards.ISIC4, "264")),
        ((Standards.NIC2008, "2640"), (Standards.ISIC4, "2640")),
        ((Standards.NIC2008, "265"), (Standards.ISIC4, "265")),
        ((Standards.NIC2008, "2651"), (Standards.ISIC4, "2651")),
        ((Standards.NIC2008, "2652"), (Standards.ISIC4, "2652")),
        ((Standards.NIC2008, "266"), (Standards.ISIC4, "266")),
        ((Standards.NIC2008, "2660"), (Standards.ISIC4, "2660")),
        ((Standards.NIC2008, "267"), (Standards.ISIC4, "267")),
        ((Standards.NIC2008, "2670"), (Standards.ISIC4, "2670")),
        ((Standards.NIC2008, "268"), (Standards.ISIC4, "268")),
        ((Standards.NIC2008, "2680"), (Standards.ISIC4, "2680")),
        ((Standards.NIC2008, "27"), (Standards.ISIC4, "27")),
        ((Standards.NIC2008, "271"), (Standards.ISIC4, "271")),
        ((Standards.NIC2008, "2710"), (Standards.ISIC4, "2710")),
        ((Standards.NIC2008, "272"), (Standards.ISIC4, "272")),
        ((Standards.NIC2008, "2720"), (Standards.ISIC4, "2720")),
        ((Standards.NIC2008, "273"), (Standards.ISIC4, "273")),
        ((Standards.NIC2008, "2731"), (Standards.ISIC4, "2731")),
        ((Standards.NIC2008, "2732"), (Standards.ISIC4, "2732")),
        ((Standards.NIC2008, "2733"), (Standards.ISIC4, "2733")),
        ((Standards.NIC2008, "274"), (Standards.ISIC4, "274")),
        ((Standards.NIC2008, "2740"), (Standards.ISIC4, "2740")),
        ((Standards.NIC2008, "275"), (Standards.ISIC4, "275")),
        ((Standards.NIC2008, "2750"), (Standards.ISIC4, "2750")),
        ((Standards.NIC2008, "279"), (Standards.ISIC4, "279")),
        ((Standards.NIC2008, "2790"), (Standards.ISIC4, "2790")),
        ((Standards.NIC2008, "28"), (Standards.ISIC4, "28")),
        ((Standards.NIC2008, "281"), (Standards.ISIC4, "281")),
        ((Standards.NIC2008, "2811"), (Standards.ISIC4, "2811")),
        ((Standards.NIC2008, "2812"), (Standards.ISIC4, "2812")),
        ((Standards.NIC2008, "2813"), (Standards.ISIC4, "2813")),
        ((Standards.NIC2008, "2814"), (Standards.ISIC4, "2814")),
        ((Standards.NIC2008, "2815"), (Standards.ISIC4, "2815")),
        ((Standards.NIC2008, "2816"), (Standards.ISIC4, "2816")),
        ((Standards.NIC2008, "2817"), (Standards.ISIC4, "2817")),
        ((Standards.NIC2008, "2818"), (Standards.ISIC4, "2818")),
        ((Standards.NIC2008, "2819"), (Standards.ISIC4, "2819")),
        ((Standards.NIC2008, "282"), (Standards.ISIC4, "282")),
        ((Standards.NIC2008, "2821"), (Standards.ISIC4, "2821")),
        ((Standards.NIC2008, "2822"), (Standards.ISIC4, "2822")),
        ((Standards.NIC2008, "2823"), (Standards.ISIC4, "2823")),
        ((Standards.NIC2008, "2824"), (Standards.ISIC4, "2824")),
        ((Standards.NIC2008, "2825"), (Standards.ISIC4, "2825")),
        ((Standards.NIC2008, "2826"), (Standards.ISIC4, "2826")),
        ((Standards.NIC2008, "2829"), (Standards.ISIC4, "2829")),
        ((Standards.NIC2008, "29"), (Standards.ISIC4, "29")),
        ((Standards.NIC2008, "291"), (Standards.ISIC4, "291")),
        ((Standards.NIC2008, "2910"), (Standards.ISIC4, "2910")),
        ((Standards.NIC2008, "292"), (Standards.ISIC4, "292")),
        ((Standards.NIC2008, "2920"), (Standards.ISIC4, "2920")),
        ((Standards.NIC2008, "293"), (Standards.ISIC4, "293")),
        ((Standards.NIC2008, "2930"), (Standards.ISIC4, "2930")),
        ((Standards.NIC2008, "30"), (Standards.ISIC4, "30")),
        ((Standards.NIC2008, "301"), (Standards.ISIC4, "301")),
        ((Standards.NIC2008, "3011"), (Standards.ISIC4, "3011")),
        ((Standards.NIC2008, "3012"), (Standards.ISIC4, "3012")),
        ((Standards.NIC2008, "302"), (Standards.ISIC4, "302")),
        ((Standards.NIC2008, "3020"), (Standards.ISIC4, "3020")),
        ((Standards.NIC2008, "303"), (Standards.ISIC4, "303")),
        ((Standards.NIC2008, "3030"), (Standards.ISIC4, "3030")),
        ((Standards.NIC2008, "304"), (Standards.ISIC4, "304")),
        ((Standards.NIC2008, "3040"), (Standards.ISIC4, "3040")),
        ((Standards.NIC2008, "309"), (Standards.ISIC4, "309")),
        ((Standards.NIC2008, "3091"), (Standards.ISIC4, "3091")),
        ((Standards.NIC2008, "3092"), (Standards.ISIC4, "3092")),
        ((Standards.NIC2008, "3099"), (Standards.ISIC4, "3099")),
        ((Standards.NIC2008, "31"), (Standards.ISIC4, "31")),
        ((Standards.NIC2008, "310"), (Standards.ISIC4, "310")),
        ((Standards.NIC2008, "3100"), (Standards.ISIC4, "3100")),
        ((Standards.NIC2008, "32"), (Standards.ISIC4, "32")),
        ((Standards.NIC2008, "321"), (Standards.ISIC4, "321")),
        ((Standards.NIC2008, "3211"), (Standards.ISIC4, "3211")),
        ((Standards.NIC2008, "3212"), (Standards.ISIC4, "3212")),
        ((Standards.NIC2008, "322"), (Standards.ISIC4, "322")),
        ((Standards.NIC2008, "3220"), (Standards.ISIC4, "3220")),
        ((Standards.NIC2008, "323"), (Standards.ISIC4, "323")),
        ((Standards.NIC2008, "3230"), (Standards.ISIC4, "3230")),
        ((Standards.NIC2008, "324"), (Standards.ISIC4, "324")),
        ((Standards.NIC2008, "3240"), (Standards.ISIC4, "3240")),
        ((Standards.NIC2008, "325"), (Standards.ISIC4, "325")),
        ((Standards.NIC2008, "3250"), (Standards.ISIC4, "3250")),
        ((Standards.NIC2008, "329"), (Standards.ISIC4, "329")),
        ((Standards.NIC2008, "3290"), (Standards.ISIC4, "3290")),
        ((Standards.NIC2008, "33"), (Standards.ISIC4, "33")),
        ((Standards.NIC2008, "331"), (Standards.ISIC4, "331")),
        ((Standards.NIC2008, "3311"), (Standards.ISIC4, "3311")),
        ((Standards.NIC2008, "3312"), (Standards.ISIC4, "3312")),
        ((Standards.NIC2008, "3313"), (Standards.ISIC4, "3313")),
        ((Standards.NIC2008, "3314"), (Standards.ISIC4, "3314")),
        ((Standards.NIC2008, "3315"), (Standards.ISIC4, "3315")),
        ((Standards.NIC2008, "3319"), (Standards.ISIC4, "3319")),
        ((Standards.NIC2008, "332"), (Standards.ISIC4, "332")),
        ((Standards.NIC2008, "3320"), (Standards.ISIC4, "3320")),
        ((Standards.NIC2008, "35"), (Standards.ISIC4, "35")),
        ((Standards.NIC2008, "351"), (Standards.ISIC4, "351")),
        ((Standards.NIC2008, "3510"), (Standards.ISIC4, "3510")),
        ((Standards.NIC2008, "352"), (Standards.ISIC4, "352")),
        ((Standards.NIC2008, "3520"), (Standards.ISIC4, "3520")),
        ((Standards.NIC2008, "353"), (Standards.ISIC4, "353")),
        ((Standards.NIC2008, "3530"), (Standards.ISIC4, "3530")),
        ((Standards.NIC2008, "36"), (Standards.ISIC4, "36")),
        ((Standards.NIC2008, "360"), (Standards.ISIC4, "360")),
        ((Standards.NIC2008, "3600"), (Standards.ISIC4, "3600")),
        ((Standards.NIC2008, "37"), (Standards.ISIC4, "37")),
        ((Standards.NIC2008, "370"), (Standards.ISIC4, "370")),
        ((Standards.NIC2008, "3700"), (Standards.ISIC4, "3700")),
        ((Standards.NIC2008, "38"), (Standards.ISIC4, "38")),
        ((Standards.NIC2008, "381"), (Standards.ISIC4, "381")),
        ((Standards.NIC2008, "3811"), (Standards.ISIC4, "3811")),
        ((Standards.NIC2008, "3812"), (Standards.ISIC4, "3812")),
        ((Standards.NIC2008, "382"), (Standards.ISIC4, "382")),
        ((Standards.NIC2008, "3821"), (Standards.ISIC4, "3821")),
        ((Standards.NIC2008, "3822"), (Standards.ISIC4, "3822")),
        ((Standards.NIC2008, "383"), (Standards.ISIC4, "383")),
        ((Standards.NIC2008, "3830"), (Standards.ISIC4, "3830")),
        ((Standards.NIC2008, "39"), (Standards.ISIC4, "39")),
        ((Standards.NIC2008, "390"), (Standards.ISIC4, "390")),
        ((Standards.NIC2008, "3900"), (Standards.ISIC4, "3900")),
        ((Standards.NIC2008, "41"), (Standards.ISIC4, "41")),
        ((Standards.NIC2008, "410"), (Standards.ISIC4, "410")),
        ((Standards.NIC2008, "4100"), (Standards.ISIC4, "4100")),
        ((Standards.NIC2008, "42"), (Standards.ISIC4, "42")),
        ((Standards.NIC2008, "421"), (Standards.ISIC4, "421")),
        ((Standards.NIC2008, "4210"), (Standards.ISIC4, "4210")),
        ((Standards.NIC2008, "422"), (Standards.ISIC4, "422")),
        ((Standards.NIC2008, "4220"), (Standards.ISIC4, "4220")),
        ((Standards.NIC2008, "429"), (Standards.ISIC4, "429")),
        ((Standards.NIC2008, "4290"), (Standards.ISIC4, "4290")),
        ((Standards.NIC2008, "43"), (Standards.ISIC4, "43")),
        ((Standards.NIC2008, "431"), (Standards.ISIC4, "431")),
        ((Standards.NIC2008, "4311"), (Standards.ISIC4, "4311")),
        ((Standards.NIC2008, "4312"), (Standards.ISIC4, "4312")),
        ((Standards.NIC2008, "432"), (Standards.ISIC4, "432")),
        ((Standards.NIC2008, "4321"), (Standards.ISIC4, "4321")),
        ((Standards.NIC2008, "4322"), (Standards.ISIC4, "4322")),
        ((Standards.NIC2008, "4329"), (Standards.ISIC4, "4329")),
        ((Standards.NIC2008, "433"), (Standards.ISIC4, "433")),
        ((Standards.NIC2008, "4330"), (Standards.ISIC4, "4330")),
        ((Standards.NIC2008, "439"), (Standards.ISIC4, "439")),
        ((Standards.NIC2008, "4390"), (Standards.ISIC4, "4390")),
        ((Standards.NIC2008, "45"), (Standards.ISIC4, "45")),
        ((Standards.NIC2008, "451"), (Standards.ISIC4, "451")),
        ((Standards.NIC2008, "4510"), (Standards.ISIC4, "4510")),
        ((Standards.NIC2008, "452"), (Standards.ISIC4, "452")),
        ((Standards.NIC2008, "4520"), (Standards.ISIC4, "4520")),
        ((Standards.NIC2008, "453"), (Standards.ISIC4, "453")),
        ((Standards.NIC2008, "4530"), (Standards.ISIC4, "4530")),
        ((Standards.NIC2008, "454"), (Standards.ISIC4, "454")),
        ((Standards.NIC2008, "4540"), (Standards.ISIC4, "4540")),
        ((Standards.NIC2008, "46"), (Standards.ISIC4, "46")),
        ((Standards.NIC2008, "461"), (Standards.ISIC4, "461")),
        ((Standards.NIC2008, "4610"), (Standards.ISIC4, "4610")),
        ((Standards.NIC2008, "462"), (Standards.ISIC4, "462")),
        ((Standards.NIC2008, "4620"), (Standards.ISIC4, "4620")),
        ((Standards.NIC2008, "463"), (Standards.ISIC4, "463")),
        ((Standards.NIC2008, "4630"), (Standards.ISIC4, "4630")),
        ((Standards.NIC2008, "464"), (Standards.ISIC4, "464")),
        ((Standards.NIC2008, "4641"), (Standards.ISIC4, "4641")),
        ((Standards.NIC2008, "4649"), (Standards.ISIC4, "4649")),
        ((Standards.NIC2008, "465"), (Standards.ISIC4, "465")),
        ((Standards.NIC2008, "4651"), (Standards.ISIC4, "4651")),
        ((Standards.NIC2008, "4652"), (Standards.ISIC4, "4652")),
        ((Standards.NIC2008, "4653"), (Standards.ISIC4, "4653")),
        ((Standards.NIC2008, "4659"), (Standards.ISIC4, "4659")),
        ((Standards.NIC2008, "466"), (Standards.ISIC4, "466")),
        ((Standards.NIC2008, "4661"), (Standards.ISIC4, "4661")),
        ((Standards.NIC2008, "4662"), (Standards.ISIC4, "4662")),
        ((Standards.NIC2008, "4663"), (Standards.ISIC4, "4663")),
        ((Standards.NIC2008, "4669"), (Standards.ISIC4, "4669")),
        ((Standards.NIC2008, "469"), (Standards.ISIC4, "469")),
        ((Standards.NIC2008, "4690"), (Standards.ISIC4, "4690")),
        ((Standards.NIC2008, "47"), (Standards.ISIC4, "47")),
        ((Standards.NIC2008, "471"), (Standards.ISIC4, "471")),
        ((Standards.NIC2008, "4711"), (Standards.ISIC4, "4711")),
        ((Standards.NIC2008, "4719"), (Standards.ISIC4, "4719")),
        ((Standards.NIC2008, "472"), (Standards.ISIC4, "472")),
        ((Standards.NIC2008, "4721"), (Standards.ISIC4, "4721")),
        ((Standards.NIC2008, "4722"), (Standards.ISIC4, "4722")),
        ((Standards.NIC2008, "4723"), (Standards.ISIC4, "4723")),
        ((Standards.NIC2008, "473"), (Standards.ISIC4, "473")),
        ((Standards.NIC2008, "4730"), (Standards.ISIC4, "4730")),
        ((Standards.NIC2008, "474"), (Standards.ISIC4, "474")),
        ((Standards.NIC2008, "4741"), (Standards.ISIC4, "4741")),
        ((Standards.NIC2008, "4742"), (Standards.ISIC4, "4742")),
        ((Standards.NIC2008, "475"), (Standards.ISIC4, "475")),
        ((Standards.NIC2008, "4751"), (Standards.ISIC4, "4751")),
        ((Standards.NIC2008, "4752"), (Standards.ISIC4, "4752")),
        ((Standards.NIC2008, "4753"), (Standards.ISIC4, "4753")),
        ((Standards.NIC2008, "4759"), (Standards.ISIC4, "4759")),
        ((Standards.NIC2008, "476"), (Standards.ISIC4, "476")),
        ((Standards.NIC2008, "4761"), (Standards.ISIC4, "4761")),
        ((Standards.NIC2008, "4762"), (Standards.ISIC4, "4762")),
        ((Standards.NIC2008, "4763"), (Standards.ISIC4, "4763")),
        ((Standards.NIC2008, "4764"), (Standards.ISIC4, "4764")),
        ((Standards.NIC2008, "477"), (Standards.ISIC4, "477")),
        ((Standards.NIC2008, "4771"), (Standards.ISIC4, "4771")),
        ((Standards.NIC2008, "4772"), (Standards.ISIC4, "4772")),
        ((Standards.NIC2008, "4773"), (Standards.ISIC4, "4773")),
        ((Standards.NIC2008, "4774"), (Standards.ISIC4, "4774")),
        ((Standards.NIC2008, "478"), (Standards.ISIC4, "478")),
        ((Standards.NIC2008, "4781"), (Standards.ISIC4, "4781")),
        ((Standards.NIC2008, "4782"), (Standards.ISIC4, "4782")),
        ((Standards.NIC2008, "4789"), (Standards.ISIC4, "4789")),
        ((Standards.NIC2008, "479"), (Standards.ISIC4, "479")),
        ((Standards.NIC2008, "4791"), (Standards.ISIC4, "4791")),
        ((Standards.NIC2008, "4799"), (Standards.ISIC4, "4799")),
        ((Standards.NIC2008, "49"), (Standards.ISIC4, "49")),
        ((Standards.NIC2008, "491"), (Standards.ISIC4, "491")),
        ((Standards.NIC2008, "4911"), (Standards.ISIC4, "4911")),
        ((Standards.NIC2008, "4912"), (Standards.ISIC4, "4912")),
        ((Standards.NIC2008, "492"), (Standards.ISIC4, "492")),
        ((Standards.NIC2008, "4921"), (Standards.ISIC4, "4921")),
        ((Standards.NIC2008, "4922"), (Standards.ISIC4, "4922")),
        ((Standards.NIC2008, "4923"), (Standards.ISIC4, "4923")),
        ((Standards.NIC2008, "493"), (Standards.ISIC4, "493")),
        ((Standards.NIC2008, "4930"), (Standards.ISIC4, "4930")),
        ((Standards.NIC2008, "50"), (Standards.ISIC4, "50")),
        ((Standards.NIC2008, "501"), (Standards.ISIC4, "501")),
        ((Standards.NIC2008, "5011"), (Standards.ISIC4, "5011")),
        ((Standards.NIC2008, "5012"), (Standards.ISIC4, "5012")),
        ((Standards.NIC2008, "502"), (Standards.ISIC4, "502")),
        ((Standards.NIC2008, "5021"), (Standards.ISIC4, "5021")),
        ((Standards.NIC2008, "5022"), (Standards.ISIC4, "5022")),
        ((Standards.NIC2008, "51"), (Standards.ISIC4, "51")),
        ((Standards.NIC2008, "511"), (Standards.ISIC4, "511")),
        ((Standards.NIC2008, "5110"), (Standards.ISIC4, "5110")),
        ((Standards.NIC2008, "512"), (Standards.ISIC4, "512")),
        ((Standards.NIC2008, "5120"), (Standards.ISIC4, "5120")),
        ((Standards.NIC2008, "52"), (Standards.ISIC4, "52")),
        ((Standards.NIC2008, "521"), (Standards.ISIC4, "521")),
        ((Standards.NIC2008, "5210"), (Standards.ISIC4, "5210")),
        ((Standards.NIC2008, "522"), (Standards.ISIC4, "522")),
        ((Standards.NIC2008, "5221"), (Standards.ISIC4, "5221")),
        ((Standards.NIC2008, "5222"), (Standards.ISIC4, "5222")),
        ((Standards.NIC2008, "5223"), (Standards.ISIC4, "5223")),
        ((Standards.NIC2008, "5224"), (Standards.ISIC4, "5224")),
        ((Standards.NIC2008, "5229"), (Standards.ISIC4, "5229")),
        ((Standards.NIC2008, "53"), (Standards.ISIC4, "53")),
        ((Standards.NIC2008, "531"), (Standards.ISIC4, "531")),
        ((Standards.NIC2008, "5310"), (Standards.ISIC4, "5310")),
        ((Standards.NIC2008, "532"), (Standards.ISIC4, "532")),
        ((Standards.NIC2008, "5320"), (Standards.ISIC4, "5320")),
        ((Standards.NIC2008, "55"), (Standards.ISIC4, "55")),
        ((Standards.NIC2008, "551"), (Standards.ISIC4, "551")),
        ((Standards.NIC2008, "5510"), (Standards.ISIC4, "5510")),
        ((Standards.NIC2008, "552"), (Standards.ISIC4, "552")),
        ((Standards.NIC2008, "5520"), (Standards.ISIC4, "5520")),
        ((Standards.NIC2008, "559"), (Standards.ISIC4, "559")),
        ((Standards.NIC2008, "5590"), (Standards.ISIC4, "5590")),
        ((Standards.NIC2008, "56"), (Standards.ISIC4, "56")),
        ((Standards.NIC2008, "561"), (Standards.ISIC4, "561")),
        ((Standards.NIC2008, "5610"), (Standards.ISIC4, "5610")),
        ((Standards.NIC2008, "562"), (Standards.ISIC4, "562")),
        ((Standards.NIC2008, "5621"), (Standards.ISIC4, "5621")),
        ((Standards.NIC2008, "5629"), (Standards.ISIC4, "5629")),
        ((Standards.NIC2008, "563"), (Standards.ISIC4, "563")),
        ((Standards.NIC2008, "5630"), (Standards.ISIC4, "5630")),
        ((Standards.NIC2008, "58"), (Standards.ISIC4, "58")),
        ((Standards.NIC2008, "581"), (Standards.ISIC4, "581")),
        ((Standards.NIC2008, "5811"), (Standards.ISIC4, "5811")),
        ((Standards.NIC2008, "5812"), (Standards.ISIC4, "5812")),
        ((Standards.NIC2008, "5813"), (Standards.ISIC4, "5813")),
        ((Standards.NIC2008, "5819"), (Standards.ISIC4, "5819")),
        ((Standards.NIC2008, "582"), (Standards.ISIC4, "582")),
        ((Standards.NIC2008, "5820"), (Standards.ISIC4, "5820")),
        ((Standards.NIC2008, "59"), (Standards.ISIC4, "59")),
        ((Standards.NIC2008, "591"), (Standards.ISIC4, "591")),
        ((Standards.NIC2008, "5911"), (Standards.ISIC4, "5911")),
        ((Standards.NIC2008, "5912"), (Standards.ISIC4, "5912")),
        ((Standards.NIC2008, "5913"), (Standards.ISIC4, "5913")),
        ((Standards.NIC2008, "5914"), (Standards.ISIC4, "5914")),
        ((Standards.NIC2008, "592"), (Standards.ISIC4, "592")),
        ((Standards.NIC2008, "5920"), (Standards.ISIC4, "5920")),
        ((Standards.NIC2008, "60"), (Standards.ISIC4, "60")),
        ((Standards.NIC2008, "601"), (Standards.ISIC4, "601")),
        ((Standards.NIC2008, "6010"), (Standards.ISIC4, "6010")),
        ((Standards.NIC2008, "602"), (Standards.ISIC4, "602")),
        ((Standards.NIC2008, "6020"), (Standards.ISIC4, "6020")),
        ((Standards.NIC2008, "61"), (Standards.ISIC4, "61")),
        ((Standards.NIC2008, "611"), (Standards.ISIC4, "611")),
        ((Standards.NIC2008, "6110"), (Standards.ISIC4, "6110")),
        ((Standards.NIC2008, "612"), (Standards.ISIC4, "612")),
        ((Standards.NIC2008, "6120"), (Standards.ISIC4, "6120")),
        ((Standards.NIC2008, "613"), (Standards.ISIC4, "613")),
        ((Standards.NIC2008, "6130"), (Standards.ISIC4, "6130")),
        ((Standards.NIC2008, "619"), (Standards.ISIC4, "619")),
        ((Standards.NIC2008, "6190"), (Standards.ISIC4, "6190")),
        ((Standards.NIC2008, "62"), (Standards.ISIC4, "62")),
        ((Standards.NIC2008, "620"), (Standards.ISIC4, "620")),
        ((Standards.NIC2008, "6201"), (Standards.ISIC4, "6201")),
        ((Standards.NIC2008, "6202"), (Standards.ISIC4, "6202")),
        ((Standards.NIC2008, "6209"), (Standards.ISIC4, "6209")),
        ((Standards.NIC2008, "63"), (Standards.ISIC4, "63")),
        ((Standards.NIC2008, "631"), (Standards.ISIC4, "631")),
        ((Standards.NIC2008, "6311"), (Standards.ISIC4, "6311")),
        ((Standards.NIC2008, "6312"), (Standards.ISIC4, "6312")),
        ((Standards.NIC2008, "639"), (Standards.ISIC4, "639")),
        ((Standards.NIC2008, "6391"), (Standards.ISIC4, "6391")),
        ((Standards.NIC2008, "6399"), (Standards.ISIC4, "6399")),
        ((Standards.NIC2008, "64"), (Standards.ISIC4, "64")),
        ((Standards.NIC2008, "641"), (Standards.ISIC4, "641")),
        ((Standards.NIC2008, "6411"), (Standards.ISIC4, "6411")),
        ((Standards.NIC2008, "6419"), (Standards.ISIC4, "6419")),
        ((Standards.NIC2008, "642"), (Standards.ISIC4, "642")),
        ((Standards.NIC2008, "6420"), (Standards.ISIC4, "6420")),
        ((Standards.NIC2008, "643"), (Standards.ISIC4, "643")),
        ((Standards.NIC2008, "6430"), (Standards.ISIC4, "6430")),
        ((Standards.NIC2008, "649"), (Standards.ISIC4, "649")),
        ((Standards.NIC2008, "6491"), (Standards.ISIC4, "6491")),
        ((Standards.NIC2008, "6492"), (Standards.ISIC4, "6492")),
        ((Standards.NIC2008, "6499"), (Standards.ISIC4, "6499")),
        ((Standards.NIC2008, "65"), (Standards.ISIC4, "65")),
        ((Standards.NIC2008, "651"), (Standards.ISIC4, "651")),
        ((Standards.NIC2008, "6511"), (Standards.ISIC4, "6511")),
        ((Standards.NIC2008, "6512"), (Standards.ISIC4, "6512")),
        ((Standards.NIC2008, "652"), (Standards.ISIC4, "652")),
        ((Standards.NIC2008, "6520"), (Standards.ISIC4, "6520")),
        ((Standards.NIC2008, "653"), (Standards.ISIC4, "653")),
        ((Standards.NIC2008, "6530"), (Standards.ISIC4, "6530")),
        ((Standards.NIC2008, "66"), (Standards.ISIC4, "66")),
        ((Standards.NIC2008, "661"), (Standards.ISIC4, "661")),
        ((Standards.NIC2008, "6611"), (Standards.ISIC4, "6611")),
        ((Standards.NIC2008, "6612"), (Standards.ISIC4, "6612")),
        ((Standards.NIC2008, "6619"), (Standards.ISIC4, "6619")),
        ((Standards.NIC2008, "662"), (Standards.ISIC4, "662")),
        ((Standards.NIC2008, "6621"), (Standards.ISIC4, "6621")),
        ((Standards.NIC2008, "6622"), (Standards.ISIC4, "6622")),
        ((Standards.NIC2008, "6629"), (Standards.ISIC4, "6629")),
        ((Standards.NIC2008, "663"), (Standards.ISIC4, "663")),
        ((Standards.NIC2008, "6630"), (Standards.ISIC4, "6630")),
        ((Standards.NIC2008, "68"), (Standards.ISIC4, "68")),
        ((Standards.NIC2008, "681"), (Standards.ISIC4, "681")),
        ((Standards.NIC2008, "6810"), (Standards.ISIC4, "6810")),
        ((Standards.NIC2008, "682"), (Standards.ISIC4, "682")),
        ((Standards.NIC2008, "6820"), (Standards.ISIC4, "6820")),
        ((Standards.NIC2008, "69"), (Standards.ISIC4, "69")),
        ((Standards.NIC2008, "691"), (Standards.ISIC4, "691")),
        ((Standards.NIC2008, "6910"), (Standards.ISIC4, "6910")),
        ((Standards.NIC2008, "692"), (Standards.ISIC4, "692")),
        ((Standards.NIC2008, "6920"), (Standards.ISIC4, "6920")),
        ((Standards.NIC2008, "70"), (Standards.ISIC4, "70")),
        ((Standards.NIC2008, "701"), (Standards.ISIC4, "701")),
        ((Standards.NIC2008, "7010"), (Standards.ISIC4, "7010")),
        ((Standards.NIC2008, "702"), (Standards.ISIC4, "702")),
        ((Standards.NIC2008, "7020"), (Standards.ISIC4, "7020")),
        ((Standards.NIC2008, "71"), (Standards.ISIC4, "71")),
        ((Standards.NIC2008, "711"), (Standards.ISIC4, "711")),
        ((Standards.NIC2008, "7110"), (Standards.ISIC4, "7110")),
        ((Standards.NIC2008, "712"), (Standards.ISIC4, "712")),
        ((Standards.NIC2008, "7120"), (Standards.ISIC4, "7120")),
        ((Standards.NIC2008, "72"), (Standards.ISIC4, "72")),
        ((Standards.NIC2008, "721"), (Standards.ISIC4, "721")),
        ((Standards.NIC2008, "7210"), (Standards.ISIC4, "7210")),
        ((Standards.NIC2008, "722"), (Standards.ISIC4, "722")),
        ((Standards.NIC2008, "7220"), (Standards.ISIC4, "7220")),
        ((Standards.NIC2008, "73"), (Standards.ISIC4, "73")),
        ((Standards.NIC2008, "731"), (Standards.ISIC4, "731")),
        ((Standards.NIC2008, "7310"), (Standards.ISIC4, "7310")),
        ((Standards.NIC2008, "732"), (Standards.ISIC4, "732")),
        ((Standards.NIC2008, "7320"), (Standards.ISIC4, "7320")),
        ((Standards.NIC2008, "74"), (Standards.ISIC4, "74")),
        ((Standards.NIC2008, "741"), (Standards.ISIC4, "741")),
        ((Standards.NIC2008, "7410"), (Standards.ISIC4, "7410")),
        ((Standards.NIC2008, "742"), (Standards.ISIC4, "742")),
        ((Standards.NIC2008, "7420"), (Standards.ISIC4, "7420")),
        ((Standards.NIC2008, "749"), (Standards.ISIC4, "749")),
        ((Standards.NIC2008, "7490"), (Standards.ISIC4, "7490")),
        ((Standards.NIC2008, "75"), (Standards.ISIC4, "75")),
        ((Standards.NIC2008, "750"), (Standards.ISIC4, "750")),
        ((Standards.NIC2008, "7500"), (Standards.ISIC4, "7500")),
        ((Standards.NIC2008, "77"), (Standards.ISIC4, "77")),
        ((Standards.NIC2008, "771"), (Standards.ISIC4, "771")),
        ((Standards.NIC2008, "7710"), (Standards.ISIC4, "7710")),
        ((Standards.NIC2008, "772"), (Standards.ISIC4, "772")),
        ((Standards.NIC2008, "7721"), (Standards.ISIC4, "7721")),
        ((Standards.NIC2008, "7722"), (Standards.ISIC4, "7722")),
        ((Standards.NIC2008, "7729"), (Standards.ISIC4, "7729")),
        ((Standards.NIC2008, "773"), (Standards.ISIC4, "773")),
        ((Standards.NIC2008, "7730"), (Standards.ISIC4, "7730")),
        ((Standards.NIC2008, "774"), (Standards.ISIC4, "774")),
        ((Standards.NIC2008, "7740"), (Standards.ISIC4, "7740")),
        ((Standards.NIC2008, "78"), (Standards.ISIC4, "78")),
        ((Standards.NIC2008, "781"), (Standards.ISIC4, "781")),
        ((Standards.NIC2008, "7810"), (Standards.ISIC4, "7810")),
        ((Standards.NIC2008, "782"), (Standards.ISIC4, "782")),
        ((Standards.NIC2008, "7820"), (Standards.ISIC4, "7820")),
        ((Standards.NIC2008, "783"), (Standards.ISIC4, "783")),
        ((Standards.NIC2008, "7830"), (Standards.ISIC4, "7830")),
        ((Standards.NIC2008, "79"), (Standards.ISIC4, "79")),
        ((Standards.NIC2008, "791"), (Standards.ISIC4, "791")),
        ((Standards.NIC2008, "7911"), (Standards.ISIC4, "7911")),
        ((Standards.NIC2008, "7912"), (Standards.ISIC4, "7912")),
        ((Standards.NIC2008, "799"), (Standards.ISIC4, "799")),
        ((Standards.NIC2008, "7990"), (Standards.ISIC4, "7990")),
        ((Standards.NIC2008, "80"), (Standards.ISIC4, "80")),
        ((Standards.NIC2008, "801"), (Standards.ISIC4, "801")),
        ((Standards.NIC2008, "8010"), (Standards.ISIC4, "8010")),
        ((Standards.NIC2008, "802"), (Standards.ISIC4, "802")),
        ((Standards.NIC2008, "8020"), (Standards.ISIC4, "8020")),
        ((Standards.NIC2008, "803"), (Standards.ISIC4, "803")),
        ((Standards.NIC2008, "8030"), (Standards.ISIC4, "8030")),
        ((Standards.NIC2008, "81"), (Standards.ISIC4, "81")),
        ((Standards.NIC2008, "811"), (Standards.ISIC4, "811")),
        ((Standards.NIC2008, "8110"), (Standards.ISIC4, "8110")),
        ((Standards.NIC2008, "812"), (Standards.ISIC4, "812")),
        ((Standards.NIC2008, "8121"), (Standards.ISIC4, "8121")),
        ((Standards.NIC2008, "8129"), (Standards.ISIC4, "8129")),
        ((Standards.NIC2008, "813"), (Standards.ISIC4, "813")),
        ((Standards.NIC2008, "8130"), (Standards.ISIC4, "8130")),
        ((Standards.NIC2008, "82"), (Standards.ISIC4, "82")),
        ((Standards.NIC2008, "821"), (Standards.ISIC4, "821")),
        ((Standards.NIC2008, "8211"), (Standards.ISIC4, "8211")),
        ((Standards.NIC2008, "8219"), (Standards.ISIC4, "8219")),
        ((Standards.NIC2008, "822"), (Standards.ISIC4, "822")),
        ((Standards.NIC2008, "8220"), (Standards.ISIC4, "8220")),
        ((Standards.NIC2008, "823"), (Standards.ISIC4, "823")),
        ((Standards.NIC2008, "8230"), (Standards.ISIC4, "8230")),
        ((Standards.NIC2008, "829"), (Standards.ISIC4, "829")),
        ((Standards.NIC2008, "8291"), (Standards.ISIC4, "8291")),
        ((Standards.NIC2008, "8292"), (Standards.ISIC4, "8292")),
        ((Standards.NIC2008, "8299"), (Standards.ISIC4, "8299")),
        ((Standards.NIC2008, "84"), (Standards.ISIC4, "84")),
        ((Standards.NIC2008, "841"), (Standards.ISIC4, "841")),
        ((Standards.NIC2008, "8411"), (Standards.ISIC4, "8411")),
        ((Standards.NIC2008, "8412"), (Standards.ISIC4, "8412")),
        ((Standards.NIC2008, "8413"), (Standards.ISIC4, "8413")),
        ((Standards.NIC2008, "842"), (Standards.ISIC4, "842")),
        ((Standards.NIC2008, "8421"), (Standards.ISIC4, "8421")),
        ((Standards.NIC2008, "8422"), (Standards.ISIC4, "8422")),
        ((Standards.NIC2008, "8423"), (Standards.ISIC4, "8423")),
        ((Standards.NIC2008, "843"), (Standards.ISIC4, "843")),
        ((Standards.NIC2008, "8430"), (Standards.ISIC4, "8430")),
        ((Standards.NIC2008, "85"), (Standards.ISIC4, "85")),
        ((Standards.NIC2008, "851"), (Standards.ISIC4, "851")),
        ((Standards.NIC2008, "8510"), (Standards.ISIC4, "8510")),
        ((Standards.NIC2008, "852"), (Standards.ISIC4, "852")),
        ((Standards.NIC2008, "8521"), (Standards.ISIC4, "8521")),
        ((Standards.NIC2008, "8522"), (Standards.ISIC4, "8522")),
        ((Standards.NIC2008, "853"), (Standards.ISIC4, "853")),
        ((Standards.NIC2008, "8530"), (Standards.ISIC4, "8530")),
        ((Standards.NIC2008, "854"), (Standards.ISIC4, "854")),
        ((Standards.NIC2008, "8541"), (Standards.ISIC4, "8541")),
        ((Standards.NIC2008, "8542"), (Standards.ISIC4, "8542")),
        ((Standards.NIC2008, "8549"), (Standards.ISIC4, "8549")),
        ((Standards.NIC2008, "855"), (Standards.ISIC4, "855")),
        ((Standards.NIC2008, "8550"), (Standards.ISIC4, "8550")),
        ((Standards.NIC2008, "86"), (Standards.ISIC4, "86")),
        ((Standards.NIC2008, "861"), (Standards.ISIC4, "861")),
        ((Standards.NIC2008, "8610"), (Standards.ISIC4, "8610")),
        ((Standards.NIC2008, "862"), (Standards.ISIC4, "862")),
        ((Standards.NIC2008, "8620"), (Standards.ISIC4, "8620")),
        ((Standards.NIC2008, "869"), (Standards.ISIC4, "869")),
        ((Standards.NIC2008, "8690"), (Standards.ISIC4, "8690")),
        ((Standards.NIC2008, "87"), (Standards.ISIC4, "87")),
        ((Standards.NIC2008, "871"), (Standards.ISIC4, "871")),
        ((Standards.NIC2008, "8710"), (Standards.ISIC4, "8710")),
        ((Standards.NIC2008, "872"), (Standards.ISIC4, "872")),
        ((Standards.NIC2008, "8720"), (Standards.ISIC4, "8720")),
        ((Standards.NIC2008, "873"), (Standards.ISIC4, "873")),
        ((Standards.NIC2008, "8730"), (Standards.ISIC4, "8730")),
        ((Standards.NIC2008, "879"), (Standards.ISIC4, "879")),
        ((Standards.NIC2008, "8790"), (Standards.ISIC4, "8790")),
        ((Standards.NIC2008, "88"), (Standards.ISIC4, "88")),
        ((Standards.NIC2008, "881"), (Standards.ISIC4, "881")),
        ((Standards.NIC2008, "8810"), (Standards.ISIC4, "8810")),
        ((Standards.NIC2008, "889"), (Standards.ISIC4, "889")),
        ((Standards.NIC2008, "8890"), (Standards.ISIC4, "8890")),
        ((Standards.NIC2008, "90"), (Standards.ISIC4, "90")),
        ((Standards.NIC2008, "900"), (Standards.ISIC4, "900")),
        ((Standards.NIC2008, "9000"), (Standards.ISIC4, "9000")),
        ((Standards.NIC2008, "91"), (Standards.ISIC4, "91")),
        ((Standards.NIC2008, "910"), (Standards.ISIC4, "910")),
        ((Standards.NIC2008, "9101"), (Standards.ISIC4, "9101")),
        ((Standards.NIC2008, "9102"), (Standards.ISIC4, "9102")),
        ((Standards.NIC2008, "9103"), (Standards.ISIC4, "9103")),
        ((Standards.NIC2008, "92"), (Standards.ISIC4, "92")),
        ((Standards.NIC2008, "920"), (Standards.ISIC4, "920")),
        ((Standards.NIC2008, "9200"), (Standards.ISIC4, "9200")),
        ((Standards.NIC2008, "93"), (Standards.ISIC4, "93")),
        ((Standards.NIC2008, "931"), (Standards.ISIC4, "931")),
        ((Standards.NIC2008, "9311"), (Standards.ISIC4, "9311")),
        ((Standards.NIC2008, "9312"), (Standards.ISIC4, "9312")),
        ((Standards.NIC2008, "9319"), (Standards.ISIC4, "9319")),
        ((Standards.NIC2008, "932"), (Standards.ISIC4, "932")),
        ((Standards.NIC2008, "9321"), (Standards.ISIC4, "9321")),
        ((Standards.NIC2008, "9329"), (Standards.ISIC4, "9329")),
        ((Standards.NIC2008, "94"), (Standards.ISIC4, "94")),
        ((Standards.NIC2008, "941"), (Standards.ISIC4, "941")),
        ((Standards.NIC2008, "9411"), (Standards.ISIC4, "9411")),
        ((Standards.NIC2008, "9412"), (Standards.ISIC4, "9412")),
        ((Standards.NIC2008, "942"), (Standards.ISIC4, "942")),
        ((Standards.NIC2008, "9420"), (Standards.ISIC4, "9420")),
        ((Standards.NIC2008, "949"), (Standards.ISIC4, "949")),
        ((Standards.NIC2008, "9491"), (Standards.ISIC4, "9491")),
        ((Standards.NIC2008, "9492"), (Standards.ISIC4, "9492")),
        ((Standards.NIC2008, "9499"), (Standards.ISIC4, "9499")),
        ((Standards.NIC2008, "95"), (Standards.ISIC4, "95")),
        ((Standards.NIC2008, "951"), (Standards.ISIC4, "951")),
        ((Standards.NIC2008, "9511"), (Standards.ISIC4, "9511")),
        ((Standards.NIC2008, "9512"), (Standards.ISIC4, "9512")),
        ((Standards.NIC2008, "952"), (Standards.ISIC4, "952")),
        ((Standards.NIC2008, "9521"), (Standards.ISIC4, "9521")),
        ((Standards.NIC2008, "9522"), (Standards.ISIC4, "9522")),
        ((Standards.NIC2008, "9523"), (Standards.ISIC4, "9523")),
        ((Standards.NIC2008, "9524"), (Standards.ISIC4, "9524")),
        ((Standards.NIC2008, "9529"), (Standards.ISIC4, "9529")),
        ((Standards.NIC2008, "96"), (Standards.ISIC4, "96")),
        ((Standards.NIC2008, "960"), (Standards.ISIC4, "960")),
        ((Standards.NIC2008, "9601"), (Standards.ISIC4, "9601")),
        ((Standards.NIC2008, "9602"), (Standards.ISIC4, "9602")),
        ((Standards.NIC2008, "9603"), (Standards.ISIC4, "9603")),
        ((Standards.NIC2008, "9609"), (Standards.ISIC4, "9609")),
        ((Standards.NIC2008, "97"), (Standards.ISIC4, "97")),
        ((Standards.NIC2008, "970"), (Standards.ISIC4, "970")),
        ((Standards.NIC2008, "9700"), (Standards.ISIC4, "9700")),
        ((Standards.NIC2008, "98"), (Standards.ISIC4, "98")),
        ((Standards.NIC2008, "981"), (Standards.ISIC4, "981")),
        ((Standards.NIC2008, "9810"), (Standards.ISIC4, "9810")),
        ((Standards.NIC2008, "982"), (Standards.ISIC4, "982")),
        ((Standards.NIC2008, "9820"), (Standards.ISIC4, "9820")),
        ((Standards.NIC2008, "99"), (Standards.ISIC4, "99")),
        ((Standards.NIC2008, "990"), (Standards.ISIC4, "990")),
        ((Standards.NIC2008, "9900"), (Standards.ISIC4, "9900")),
    ],
)
